Learn R Programming

tidygeocoder (version 1.0.0)

geo_census: Convenience functions for calling the geo function with a specified method.

Description

Convenience functions for calling the geo function with a specified method.

Usage

geo_census(...)

geo_osm(...)

geo_geocodio(...)

geo_iq(...)

Arguments

...

arguments to be passed to the geo function